"use strict";

var _myF = _interopRequireDefault(require("@antv/my-f2"));

var _methods = _interopRequireDefault(require("../mixins/methods"));

var _util = _interopRequireDefault(require("../util"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

Component({
  mixins: [_methods.default],
  props: {
    categories: [],
    series: [],
    xAxis: {
      tickCount: 3
    },
    yAxis: {
      tickCount: 3
    },
    tooltip: false
  },
  didMount: function didMount() {
    var _this = this;

    my.call('getStartupParams', {}, function (result) {
      _util.default.tracert('k', result.appId, result.url);
    });
    var id = "am-mc-k-".concat(this.$id);
    var ctx = my.createCanvasContext(id);
    var canvas = this.canvas = new _myF.default.Renderer(ctx);
    var pixelRatio = my.getSystemInfoSync().pixelRatio;
    ctx.scale(pixelRatio, pixelRatio);
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length) {
        return;
      }

      var _res$ = res[0],
          width = _res$.width,
          height = _res$.height;

      _this.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      });

      var _this$props = _this.props,
          padding = _this$props.padding,
          appendPadding = _this$props.appendPadding;
      _this.chart = new _myF.default.Chart({
        el: canvas,
        width: width,
        height: height,
        padding: padding,
        appendPadding: appendPadding
      });
    });
  },
  didUpdate: function didUpdate() {
    var _this$props2 = this.props,
        series = _this$props2.series,
        xAxis = _this$props2.xAxis,
        yAxis = _this$props2.yAxis,
        tooltip = _this$props2.tooltip,
        guide = _this$props2.guide;
    var chart = this.chart;
    chart.clear();
    var data = series.map(function (item) {
      return Object.assign({}, item, {
        range: [item.start, item.end, item.max, item.min],
        trend: item.start <= item.end ? 0 : 1
      });
    });
    chart.source(data);

    if (xAxis) {
      xAxis.label = _util.default.label;
      chart.scale('time', _util.default.scale(xAxis));
      chart.axis('time', _util.default.axis(xAxis));
    }

    if (yAxis) {
      chart.scale('range', _util.default.scale(yAxis));
      chart.axis('range', _util.default.axis(yAxis));
    }

    chart.tooltip(tooltip);
    chart.legend(false);
    chart.schema().position('time*range').color('trend', function (trend) {
      return ['#F4333C', '#1CA93D'][trend];
    }).shape('candle');

    if (guide) {
      if (guide.line) {
        chart.guide().line(guide.line);
      }

      if (guide.text) {
        chart.guide().text(guide.text);
      }
    }

    chart.render();
  }
});