"use strict";

var _myF = _interopRequireDefault(require("@antv/my-f2"));

var _methods = _interopRequireDefault(require("../mixins/methods"));

var _util = _interopRequireDefault(require("../util"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

Component({
  mixins: [_methods.default],
  props: {
    categories: [],
    series: [],
    xAxis: {
      tickCount: 3
    },
    yAxis: {
      tickCount: 3
    },
    tooltip: false,
    legend: false
  },
  didMount: function didMount() {
    var _this = this;

    my.call('getStartupParams', {}, function (result) {
      _util.default.tracert('line', result.appId, result.url);
    });
    var id = "am-mc-line-".concat(this.$id);
    var ctx = my.createCanvasContext(id);
    var canvas = this.canvas = new _myF.default.Renderer(ctx);
    var pixelRatio = my.getSystemInfoSync().pixelRatio;
    ctx.scale(pixelRatio, pixelRatio);
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length) {
        return;
      }

      var _res$ = res[0],
          width = _res$.width,
          height = _res$.height;

      _this.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      });

      var _this$props = _this.props,
          padding = _this$props.padding,
          appendPadding = _this$props.appendPadding;
      _this.chart = new _myF.default.Chart({
        el: canvas,
        width: width,
        height: height,
        padding: padding,
        appendPadding: appendPadding
      });
    });
  },
  didUpdate: function didUpdate() {
    var _this$props2 = this.props,
        categories = _this$props2.categories,
        series = _this$props2.series,
        xAxis = _this$props2.xAxis,
        yAxis = _this$props2.yAxis,
        tooltip = _this$props2.tooltip,
        legend = _this$props2.legend;
    var chart = this.chart;
    chart.clear();
    var data = [];

    if (series.length === 1) {
      data = series[0].data.map(function (item, i) {
        return {
          key: categories[i],
          value: item
        };
      });
    } else if (series.length > 1) {
      series.forEach(function (kind) {
        data = data.concat(kind.data.map(function (item, i) {
          return {
            key: categories[i],
            value: item,
            type: kind.type
          };
        }));
      });
    }

    chart.source(data);

    if (xAxis) {
      xAxis.label = _util.default.label;
      chart.scale('key', _util.default.scale(xAxis));
      chart.axis('key', _util.default.axis(xAxis));
    }

    if (yAxis) {
      chart.scale('value', _util.default.scale(yAxis));
      chart.axis('value', _util.default.axis(yAxis));
    }

    chart.tooltip(tooltip);
    chart.legend(legend);
    var style = {};
    series.forEach(function (kind) {
      style[kind.type] = kind.style;
    });
    var color = {};
    series.forEach(function (kind) {
      color[kind.type] = kind.color;
    });

    if (series.length === 1) {
      chart.line().position('key*value').color('type', function (type) {
        return color[type];
      }).shape('type', function (type) {
        return style[type] || 'line';
      });

      if (series[0].point) {
        chart.point().position('key*value').style(series[0].point);
      }
    } else if (series.length > 1) {
      chart.line().position('key*value').color('type', function (type) {
        return color[type];
      }).shape('type', function (type) {
        return style[type] || 'line';
      });
      var pointType = [];
      var pointStyle;
      series.forEach(function (kind) {
        if (kind.point) {
          pointType.push(kind.type);
          pointStyle = kind.point;
        }
      });

      if (pointType.length) {
        chart.point().position('key*value').color('type', function (type) {
          return color[type];
        }).size('type', function (v) {
          if (pointType.indexOf(v) === -1) {
            return 0;
          }
        }).style(pointStyle);
      }
    }

    chart.render();
  }
});