"use strict";

var _myF = _interopRequireDefault(require("@antv/my-f2"));

var _methods = _interopRequireDefault(require("../mixins/methods"));

var _util = _interopRequireDefault(require("../util"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

Component({
  mixins: [_methods.default],
  props: {
    series: [],
    tooltip: false,
    legend: false
  },
  didMount: function didMount() {
    var _this = this;

    my.call('getStartupParams', {}, function (result) {
      _util.default.tracert('scatter', result.appId, result.url);
    });
    var id = "am-mc-scatter-".concat(this.$id);
    var ctx = my.createCanvasContext(id);
    var canvas = this.canvas = new _myF.default.Renderer(ctx);
    var pixelRatio = my.getSystemInfoSync().pixelRatio;
    ctx.scale(pixelRatio, pixelRatio);
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length) {
        return;
      }

      var _res$ = res[0],
          width = _res$.width,
          height = _res$.height;

      _this.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      });

      var _this$props = _this.props,
          padding = _this$props.padding,
          appendPadding = _this$props.appendPadding;
      _this.chart = new _myF.default.Chart({
        el: canvas,
        width: width,
        height: height,
        padding: padding,
        appendPadding: appendPadding
      });
    });
  },
  didUpdate: function didUpdate() {
    var _this$props2 = this.props,
        series = _this$props2.series,
        xAxis = _this$props2.xAxis,
        yAxis = _this$props2.yAxis,
        tooltip = _this$props2.tooltip,
        legend = _this$props2.legend,
        style = _this$props2.style;
    var chart = this.chart;
    chart.clear();
    var data = [];

    if (series.length === 1) {
      series[0].data.forEach(function (item) {
        item.type = series[0].type;
      });
      data = series[0].data;
    } else if (series.length > 1) {
      series.forEach(function (item, i) {
        item.data.forEach(function (item2) {
          item2.type = item.type || i;
        });
        data = data.concat(item.data);
      });
    }

    chart.source(data);

    if (xAxis) {
      xAxis.label = _util.default.label;
      chart.scale('key', _util.default.scale(xAxis));
      chart.axis('key', _util.default.axis(xAxis));
    }

    if (yAxis) {
      chart.scale('value', _util.default.scale(yAxis));
      chart.axis('value', _util.default.axis(yAxis));
    }

    chart.tooltip(tooltip);
    chart.legend(legend);
    var color = [];
    var size = [];
    var dftColors = _myF.default.Global.colors;
    var length = dftColors.length;
    series.forEach(function (kind, i) {
      color.push(kind.color || dftColors[i % length]);
      size.push(kind.size || 3);
    });
    chart.point().position('key*value').color('type', color).size('type', size).style(style);
    chart.render();
  }
});