"use strict";

var _myF = _interopRequireDefault(require("@antv/my-f2"));

var _methods = _interopRequireDefault(require("../mixins/methods"));

var _util = _interopRequireDefault(require("../util"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

Component({
  mixins: [{
    methods: {
      touchStartArea: function touchStartArea(e) {
        if (this.areaCanvas) {
          this.areaCanvas.emitEvent('touchstart', [e]);
        }
      },
      touchMoveArea: function touchMoveArea(e) {
        if (this.areaCanvas) {
          this.areaCanvas.emitEvent('touchmove', [e]);
        }
      },
      touchEndArea: function touchEndArea(e) {
        if (this.areaCanvas) {
          this.areaCanvas.emitEvent('touchend', [e]);
        }
      },
      touchStartColumn: function touchStartColumn(e) {
        if (this.columnCanvas) {
          this.columnCanvas.emitEvent('touchstart', [e]);
        }
      },
      touchMoveColumn: function touchMoveColumn(e) {
        if (this.columnCanvas) {
          this.columnCanvas.emitEvent('touchmove', [e]);
        }
      },
      touchEndColumn: function touchEndColumn(e) {
        if (this.columnCanvas) {
          this.columnCanvas.emitEvent('touchend', [e]);
        }
      }
    }
  }],
  props: {
    series: [],
    xAxis: {
      tickCount: 3
    },
    yAxis: {
      tickCount: 3
    },
    appendPadding: 15,
    tooltip: false
  },
  didMount: function didMount() {
    var _this = this;

    my.call('getStartupParams', {}, function (result) {
      _util.default.tracert('timeshare', result.appId, result.url);
    });
    var areaId = "am-mc-timeshare-area-".concat(this.$id);
    var areaCtx = my.createCanvasContext(areaId);
    var areaCanvas = this.areaCanvas = new _myF.default.Renderer(areaCtx);
    var areaChart;
    var columnId = "am-mc-timeshare-column-".concat(this.$id);
    var columnCtx = my.createCanvasContext(columnId);
    var columnCanvas = this.columnCanvas = new _myF.default.Renderer(columnCtx);
    var columnChart;
    var pixelRatio = my.getSystemInfoSync().pixelRatio;
    areaCtx.scale(pixelRatio, pixelRatio);
    columnCtx.scale(pixelRatio, pixelRatio);
    my.createSelectorQuery().select("#".concat(areaId)).boundingClientRect().select("#".concat(columnId)).boundingClientRect().exec(function (res) {
      if (!res || !res.length) {
        return;
      }

      var _res$ = res[0],
          widthArea = _res$.width,
          heightArea = _res$.height;
      var _res$2 = res[1],
          widthColumn = _res$2.width,
          heightColumn = _res$2.height;

      _this.setData({
        widthArea: widthArea * pixelRatio,
        heightArea: heightArea * pixelRatio,
        widthColumn: widthColumn * pixelRatio,
        heightColumn: heightColumn * pixelRatio
      });

      var _this$props = _this.props,
          padding = _this$props.padding,
          appendPadding = _this$props.appendPadding;

      if (!Array.isArray(appendPadding)) {
        appendPadding = [appendPadding, appendPadding, appendPadding, appendPadding];
      }

      var columnAppendPadding = Object.assign([], appendPadding);
      columnAppendPadding[0] = 0;
      _this.areaChart = new _myF.default.Chart({
        el: areaCanvas,
        width: widthArea,
        height: heightArea,
        padding: padding,
        appendPadding: appendPadding
      });
      _this.columnChart = new _myF.default.Chart({
        el: columnCanvas,
        width: widthColumn,
        height: heightColumn,
        appendPadding: columnAppendPadding
      });
    });
  },
  didUpdate: function didUpdate() {
    var _this$props2 = this.props,
        series = _this$props2.series,
        xAxis = _this$props2.xAxis,
        yAxis = _this$props2.yAxis,
        tooltip = _this$props2.tooltip,
        guide = _this$props2.guide;
    var areaChart = this.areaChart;
    areaChart.clear();
    var columnChart = this.columnChart;
    columnChart.clear();
    var price = [];
    var data = series.map(function (item) {
      price.push(item.price);
      return {
        key: item.time,
        value: item.price,
        type: 'a'
      };
    });
    areaChart.source(data);

    if (xAxis) {
      xAxis.label = _util.default.label;
      areaChart.scale('key', _util.default.scale(xAxis));
      areaChart.axis('key', _util.default.axis(xAxis));
    }

    if (yAxis) {
      areaChart.scale('value', _util.default.scale(yAxis));
      areaChart.axis('value', _util.default.axis(yAxis));
    }

    areaChart.tooltip(Object.assign(tooltip, {
      onChange: function onChange(obj) {
        var currentPoint = {
          x: obj.x,
          y: obj.y
        };
        columnChart.showTooltip(currentPoint);
      }
    }));
    areaChart.legend(false);
    areaChart.area().position('key*value').color('type');
    areaChart.line().position('key*value').color('type');

    if (guide) {
      if (guide.line) {
        areaChart.guide().line(guide.line);
      }

      if (guide.text) {
        areaChart.guide().text(guide.text);
      }
    }

    areaChart.render();

    if (!series || !series.length) {
      return;
    }

    var lastVolume = series[0].volume;
    data = series.map(function (item, i) {
      var res = i ? {
        trend: item.price >= series[i - 1].price ? 0 : 1,
        key: item.time,
        value: item.volume - lastVolume
      } : {
        trend: 0,
        key: item.time,
        value: item.volume
      };
      lastVolume = item.volume;
      return res;
    });
    columnChart.source(data);
    columnChart.interval().position('key*value').color('trend', function (item) {
      return ['#FF4433', '#32A532'][item];
    });

    if (tooltip) {
      columnChart.tooltip(Object.assign(tooltip, {
        crosshairsType: 'y',
        custom: true,
        onChange: function onChange(obj) {
          var currentPoint = {
            x: obj.x,
            y: obj.y
          };
          areaChart.showTooltip(currentPoint);
        }
      }));
    } else {
      columnChart.tooltip(false);
    }

    columnChart.legend(false);
    columnChart.axis(false);
    columnChart.render();
  }
});